@@ -3,18 +3,13 @@
 
 # imports.
 from syst3m.classes.config import *
-from syst3m.classes import objects, defaults
-from syst3m.classes.defaults import kill, processes
-# exceptions.
-class NetworkError(Exception):
-	pass
 
 # the cache object class.
-class Cache(objects.Object):
+class Cache(Object):
 	def __init__(self, path=None):
 		if path == None: path = f"{HOME}/.cache/"
 		if not Files.exists(path): Files.create(path, directory=True)
-		objects.Object.__init__(self)
+		Object.__init__(self)
 		self.assign({
 			"path":path,
 		})
@@ -109,12 +104,12 @@ class WebServer(objects.Thread):
 		try:
 			response = requests.get(f'http://{self.host}:{self.port}/set?{encoded}', timeout=timeout)
 		except Exception as e:
-			return r3sponse.error(f"Failed to connect with {self.host}:{self.port}, error: {e}")
+			return Response.error(f"Failed to connect with {self.host}:{self.port}, error: {e}")
 		try:
 			response = self.__serialize__(response.json())
 		except:
-			return r3sponse.error(f"Failed to serialize {response}: {response.text}")
-		return r3sponse.response(response)
+			return Response.error(f"Failed to serialize {response}: {response.text}")
+		return Response.response(response)
 	def get(self, group=None, id=None, timeout=3):
 		encoded = urllib.parse.urlencode({
 			"group":group.replace(" ","_"),
@@ -126,12 +121,12 @@ class WebServer(objects.Thread):
 		try:
 			response = requests.get(f'http://{self.host}:{self.port}/get?{encoded}', timeout=timeout)
 		except Exception as e:
-			return r3sponse.error(f"Failed to connect with {self.host}:{self.port}, error: {e}")
+			return Response.error(f"Failed to connect with {self.host}:{self.port}, error: {e}")
 		try:
 			response = self.__serialize__(response.json())
 		except:
-			return r3sponse.error(f"Failed to serialize {response}: {response.text}")
-		return r3sponse.response(response,)
+			return Response.error(f"Failed to serialize {response}: {response.text}")
+		return Response.response(response,)
 	# flask app.
 	def app(self):
 		app = flask.Flask(__name__)
@@ -141,7 +136,7 @@ class WebServer(objects.Thread):
 		def get():
 			token = flask.request.args.get('token')
 			if token != Cache(path=flask.request.args.get('cache')).get(flask.request.args.get('cache_id'), id="token"):
-				return r3sponse.error(f"Provided an invalid token {token}.").json()
+				return Response.error(f"Provided an invalid token {token}.").json()
 			group = flask.request.args.get('group')
 			id = flask.request.args.get('id')
 			if id in ["none", "null", "None"]: id = None
@@ -153,8 +148,8 @@ class WebServer(objects.Thread):
 					tag = f"{group}:{id}"
 					value = self.cache[group][id]
 			except KeyError:
-				return r3sponse.error(f"There is no data cached for {tag}.").json()
-			return r3sponse.success(f"Successfully retrieved {tag}.", {
+				return Response.error(f"There is no data cached for {tag}.").json()
+			return Response.success(f"Successfully retrieved {tag}.", {
 				"group":group,
 				"id":id,
 				"data":value,
@@ -163,7 +158,7 @@ class WebServer(objects.Thread):
 		def set():
 			token = flask.request.args.get('token')
 			if token != Cache(path=flask.request.args.get('cache')).get(flask.request.args.get('cache_id'), id="token"):
-				return r3sponse.error(f"Provided an invalid token {token}.").json()
+				return Response.error(f"Provided an invalid token {token}.").json()
 			group = flask.request.args.get('group')
 			id = flask.request.args.get('id')
 			if id in ["none", "null", "None"]: id = None
@@ -176,13 +171,13 @@ class WebServer(objects.Thread):
 				try: self.cache[group]
 				except KeyError: self.cache[group] = {}
 				self.cache[group][id] = value
-			return r3sponse.success(f"Successfully cached {tag}.").json()
+			return Response.success(f"Successfully cached {tag}.").json()
 		@app.route('/active')
 		def active():
 			token = flask.request.args.get('token')
 			if token != Cache(path=flask.request.args.get('cache')).get(flask.request.args.get('cache_id'), id="token"):
-				return r3sponse.error(f"Provided an invalid token {token}.").json()
-			return r3sponse.success(f"Active.").json()
+				return Response.error(f"Provided an invalid token {token}.").json()
+			return Response.success(f"Active.").json()
 		#def run__(self, app, host, port):
 		#	app.run(host=host, port=port)
 		#self.process = multiprocessing.Process(target=app.run, args=(self, app, self.host,self.port,))
@@ -196,7 +191,7 @@ class WebServer(objects.Thread):
 		self.__cache__.set(group=self.id, id="daemon", data="*stopped*")
 	def fork(self, timeout=15, sleeptime=1):
 		if self.running:
-			return r3sponse.error(f"The {self.id} is already running.")
+			return Response.error(f"The {self.id} is already running.")
 		if self.log_level <= 0:
 			print(f"Starting the {self.id}.")
 		serialized = self.dict()
@@ -205,7 +200,7 @@ class WebServer(objects.Thread):
 			try: del serialized[i]
 			except: a=1
 		serialized = f"{serialized}"
-		command = [defaults.vars.python3, f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", self.tag]
+		command = [Defaults.vars.executable, f"{SOURCE_PATH}classes/cache/fork.py", "--serialized", f"'{serialized}'", "--syst3m-webserver-tag", self.tag]
 		if self.log_level < 0:
 			command += [ "2>", "/dev/null"]
 		p = subprocess.Popen(command)
@@ -216,21 +211,21 @@ class WebServer(objects.Thread):
 				break
 			time.sleep(sleeptime)
 		if success:
-			return r3sponse.success(f"Successfully started the {self.id}.")
+			return Response.success(f"Successfully started the {self.id}.")
 		else:
-			return r3sponse.error(f"The {self.id} is already running.")
+			return Response.error(f"The {self.id} is already running.")
 	def stop(self):
 		if not self.running: 
-			return r3sponse.error(f"{self.__traceback__(function='stop')}: The {self.id} is not running.")
-		processes = processes(includes=f"--syst3m-webserver-tag {self.tag}")
+			return Response.error(f"{self.__traceback__(function='stop')}: The {self.id} is not running.")
+		processes = Defaults.processes(includes=f"--syst3m-webserver-tag {self.tag}")
 		if not processes.success: return response
 		if len(processes.processes) <= 1:
-			return r3sponse.error(f"Unable to find the pid of the {self.id}.")
+			return Response.error(f"Unable to find the pid of the {self.id}.")
 		for pid, info in processes.processes.items():
 			if info["process"] not in ["grep"]:
-				response = kill(pid=pid)
+				response = Defaults.kill(pid=pid)
 				if not response.success: return response
-		return r3sponse.error(f"Successfully stopped the {self.id}.")
+		return Response.error(f"Successfully stopped the {self.id}.")
 	# threading functions.
 	def start_thread(self, thread, group="daemons", id=None):
 		response = self.set(group=group, id=id, data=thread)
@@ -244,15 +239,15 @@ class WebServer(objects.Thread):
 			id = thread.id
 		except:
 			id = str(thread)
-		return r3sponse.success(f"Successfully started [{id}].")
+		return Response.success(f"Successfully started [{id}].")
 	def get_thread(self, group="daemos", id=None):
 		response = self.get(group=group, id=id)
 		if not response.success: 
 			if "There is no data cached for" in response.error:
-				return r3sponse.error(f"There is no thread cached for (group: {group}), (id: {id}).")
+				return Response.error(f"There is no thread cached for (group: {group}), (id: {id}).")
 			else: return response
 		thread = response.data
-		return r3sponse.success(f"Successfully retrieved thread [{thread}].", {
+		return Response.success(f"Successfully retrieved thread [{thread}].", {
 			"thread":thread,
 		})
 	# properties.
