@@ -60,7 +60,7 @@ def __check_alias__(
 		sys.exit(0)
 
 # source.
-from fil3s import *
+from dev0s import *
 ALIAS = "syst3m"
 SOURCE_NAME = "syst3m"
 SOURCE_PATH = gfp.base(path=__file__, back=3)
@@ -73,25 +73,18 @@ try:
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading, urllib, flask, logging, multiprocessing
 
 	# inc imports.
-	import cl1
-	from fil3s import *
-	from r3sponse import r3sponse
+	from dev0s import *
 
 # download.
 except ImportError as e:
 	import syst3m
-	syst3m.defaults.install_requirements(f"{sys.executable} -m pip install -r {FilePath(__file__).base(back=3)}/requirements/requirements.pip")
+	Defaults.install_requirements(f"{sys.executable} -m pip install -r {FilePath(__file__).base(back=3)}/requirements/requirements.pip")
 
 	# pip imports.
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading, urllib, flask, logging, multiprocessing
 
 	# inc imports.
-	import cl1
-	from fil3s import *
-	from r3sponse import r3sponse
-
-# imports.
-from r3sponse import ResponseObject
+	from dev0s import *
 
 # universal variables.
 USER = os.environ.get("USER")
